Documentation
¶
Overview ¶
Package caa provides an easy way to access Cover Art Archive.
Cover Art Archive (CAA) is a project with a goal to make cover art images available to everyone on the Internet in an organized and convinient format. More informantion is available at https://coverartarchive.org/.
There are two supported MusicBrainz ID (MBID) types for retrieval from CAA:
- release
- release group
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Scheme = "https" // http or https Host = "coverartarchive.org" )
Functions ¶
This section is empty.
Types ¶
type Image ¶
type Image struct {
ID int `json:"id"`
Image string `json:"image"` // Full URL to the original image
Types []string `json:"types"` // List of zero or more types for the image (https://musicbrainz.org/doc/Cover_Art/Types)
IsFront bool `json:"front"`
IsBack bool `json:"back"`
Thumbnails thumbnails `json:"thumbnails"`
Approved bool `json:"approved"` // Whether the image was approved by the MusicBrainz edit system
Comment string `json:"comment"` // A free text comment
Edit int `json:"edit"` // Edit ID on MusicBrainz
}
func GetRelease ¶
GetRelease returns list of cover art images for release with a specified MusicBrainz ID.
func GetReleaseGroup ¶
GetReleaseGroup returns list of cover art images for release group with a specified MusicBrainz ID.
Click to show internal directories.
Click to hide internal directories.